<?php

namespace Sahbaj\Sahbaj\Http\Controllers;

use App\Http\Controllers\AdminApiController as AdminController;
use Sahbaj\Sahbaj\Http\Requests\SahbajAdminApiRequest;
use Sahbaj\Sahbaj\Interfaces\SahbajRepositoryInterface;
use Sahbaj\Sahbaj\Models\Sahbaj;

/**
 * Admin API controller class.
 */
class SahbajAdminApiController extends AdminController
{
    /**
     * Initialize sahbaj controller.
     *
     * @param type SahbajRepositoryInterface $sahbaj
     *
     * @return type
     */
    public function __construct(SahbajRepositoryInterface $sahbaj)
    {
        $this->repository = $sahbaj;
        parent::__construct();
    }

    /**
     * Display a list of sahbaj.
     *
     * @return json
     */
    public function index(SahbajAdminApiRequest $request)
    {
        $sahbajs  = $this->repository
            ->setPresenter('\\Sahbaj\\Sahbaj\\Repositories\\Presenter\\SahbajListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->all();
        $sahbajs['code'] = 2000;
        return response()->json($sahbajs) 
                         ->setStatusCode(200, 'INDEX_SUCCESS');

    }

    /**
     * Display sahbaj.
     *
     * @param Request $request
     * @param Model   Sahbaj
     *
     * @return Json
     */
    public function show(SahbajAdminApiRequest $request, Sahbaj $sahbaj)
    {
        $sahbaj         = $sahbaj->presenter();
        $sahbaj['code'] = 2001;
        return response()->json($sahbaj)
                         ->setStatusCode(200, 'SHOW_SUCCESS');;

    }

    /**
     * Show the form for creating a new sahbaj.
     *
     * @param Request $request
     *
     * @return json
     */
    public function create(SahbajAdminApiRequest $request, Sahbaj $sahbaj)
    {
        $sahbaj         = $sahbaj->presenter();
        $sahbaj['code'] = 2002;
        return response()->json($sahbaj)
                         ->setStatusCode(200, 'CREATE_SUCCESS');

    }

    /**
     * Create new sahbaj.
     *
     * @param Request $request
     *
     * @return json
     */
    public function store(SahbajAdminApiRequest $request)
    {
        try {
            $attributes             = $request->all();
            $attributes['user_id']  = user_id('admin.api');
            $sahbaj          = $this->repository->create($attributes);
            $sahbaj          = $sahbaj->presenter();
            $sahbaj['code']  = 2004;

            return response()->json($sahbaj)
                             ->setStatusCode(201, 'STORE_SUCCESS');
        } catch (Exception $e) {
            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4004,
            ])->setStatusCode(400, 'STORE_ERROR');
;
        }
    }

    /**
     * Show sahbaj for editing.
     *
     * @param Request $request
     * @param Model   $sahbaj
     *
     * @return json
     */
    public function edit(SahbajAdminApiRequest $request, Sahbaj $sahbaj)
    {
        $sahbaj         = $sahbaj->presenter();
        $sahbaj['code'] = 2003;
        return response()-> json($sahbaj)
                        ->setStatusCode(200, 'EDIT_SUCCESS');;
    }

    /**
     * Update the sahbaj.
     *
     * @param Request $request
     * @param Model   $sahbaj
     *
     * @return json
     */
    public function update(SahbajAdminApiRequest $request, Sahbaj $sahbaj)
    {
        try {

            $attributes = $request->all();

            $sahbaj->update($attributes);
            $sahbaj         = $sahbaj->presenter();
            $sahbaj['code'] = 2005;

            return response()->json($sahbaj)
                             ->setStatusCode(201, 'UPDATE_SUCCESS');


        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4005,
            ])->setStatusCode(400, 'UPDATE_ERROR');

        }
    }

    /**
     * Remove the sahbaj.
     *
     * @param Request $request
     * @param Model   $sahbaj
     *
     * @return json
     */
    public function destroy(SahbajAdminApiRequest $request, Sahbaj $sahbaj)
    {

        try {

            $t = $sahbaj->delete();

            return response()->json([
                'message'  => trans('messages.success.delete', ['Module' => trans('sahbaj::sahbaj.name')]),
                'code'     => 2006
            ])->setStatusCode(202, 'DESTROY_SUCCESS');

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4006,
            ])->setStatusCode(400, 'DESTROY_ERROR');
        }
    }
}
