<?php

namespace Sahbaj\Sahbaj\Providers;

use Illuminate\Support\ServiceProvider;

class SahbajServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../../../resources/views', 'sahbaj');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../../../resources/lang', 'sahbaj');

        // Call pblish redources function
        $this->publishResources();

        include __DIR__ . '/../Http/routes.php';
    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('sahbaj', function ($app) {
            return $this->app->make('Sahbaj\Sahbaj\Sahbaj');
        });

        // Bind Sahbaj to repository
        $this->app->bind(
            \Sahbaj\Sahbaj\Interfaces\SahbajRepositoryInterface::class,
            \Sahbaj\Sahbaj\Repositories\Eloquent\SahbajRepository::class
        );

        $this->app->register(\Sahbaj\Sahbaj\Providers\AuthServiceProvider::class);
        $this->app->register(\Sahbaj\Sahbaj\Providers\EventServiceProvider::class);
        $this->app->register(\Sahbaj\Sahbaj\Providers\RouteServiceProvider::class);
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['sahbaj'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../../../config/config.php' => config_path('package/sahbaj.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../../../resources/views' => base_path('resources/views/vendor/sahbaj')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../../../resources/lang' => base_path('resources/lang/vendor/sahbaj')], 'lang');

        // Publish migrations
        $this->publishes([__DIR__ . '/../../../../database/migrations/' => base_path('database/migrations')], 'migrations');

        // Publish seeds
        $this->publishes([__DIR__ . '/../../../../database/seeds/' => base_path('database/seeds')], 'seeds');
    }
}
